@@ -87,8 +87,8 @@ class ElasticTranscoderClient:
     def create_job(
         self,
         PipelineId: str,
-        Input: JobInputTypeDef = None,
-        Inputs: List[JobInputTypeDef] = None,
+        Input: "JobInputTypeDef" = None,
+        Inputs: List["JobInputTypeDef"] = None,
         Output: CreateJobOutputTypeDef = None,
         Outputs: List[CreateJobOutputTypeDef] = None,
         OutputKeyPrefix: str = None,
@@ -106,9 +106,9 @@ class ElasticTranscoderClient:
         Role: str,
         OutputBucket: str = None,
         AwsKmsKeyArn: str = None,
-        Notifications: NotificationsTypeDef = None,
-        ContentConfig: PipelineOutputConfigTypeDef = None,
-        ThumbnailConfig: PipelineOutputConfigTypeDef = None,
+        Notifications: "NotificationsTypeDef" = None,
+        ContentConfig: "PipelineOutputConfigTypeDef" = None,
+        ThumbnailConfig: "PipelineOutputConfigTypeDef" = None,
     ) -> CreatePipelineResponseTypeDef:
         """
         [Client.create_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
@@ -119,9 +119,9 @@ class ElasticTranscoderClient:
         Name: str,
         Container: str,
         Description: str = None,
-        Video: VideoParametersTypeDef = None,
-        Audio: AudioParametersTypeDef = None,
-        Thumbnails: ThumbnailsTypeDef = None,
+        Video: "VideoParametersTypeDef" = None,
+        Audio: "AudioParametersTypeDef" = None,
+        Thumbnails: "ThumbnailsTypeDef" = None,
     ) -> CreatePresetResponseTypeDef:
         """
         [Client.create_preset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
@@ -205,16 +205,16 @@ class ElasticTranscoderClient:
         InputBucket: str = None,
         Role: str = None,
         AwsKmsKeyArn: str = None,
-        Notifications: NotificationsTypeDef = None,
-        ContentConfig: PipelineOutputConfigTypeDef = None,
-        ThumbnailConfig: PipelineOutputConfigTypeDef = None,
+        Notifications: "NotificationsTypeDef" = None,
+        ContentConfig: "PipelineOutputConfigTypeDef" = None,
+        ThumbnailConfig: "PipelineOutputConfigTypeDef" = None,
     ) -> UpdatePipelineResponseTypeDef:
         """
         [Client.update_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
         """
 
     def update_pipeline_notifications(
-        self, Id: str, Notifications: NotificationsTypeDef
+        self, Id: str, Notifications: "NotificationsTypeDef"
     ) -> UpdatePipelineNotificationsResponseTypeDef:
         """
         [Client.update_pipeline_notifications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
